@@ -77,7 +77,13 @@ edit_profile(GtkWidget* button, user_data_t *data)
 gboolean 
 is_profile_name_valid(const gchar* profile_name)
 {
-  return !profile_has_profile(profile_name);
+  gboolean valid = FALSE;
+  gchar* name = g_strdup(profile_name);
+  g_strstrip(name);
+  if(strlen(name) > 0)
+    valid = !profile_has_profile(name);
+  g_free(name);
+  return valid;
 }
 
 void
@@ -124,8 +130,6 @@ ask_user_for_profile_name(user_data_t* data)
   int ret = 0;
   gboolean name_is_valid = FALSE;
 
-
-
   do{
     ret = gtk_dialog_run(GTK_DIALOG(dialog));
     if(ret == GTK_RESPONSE_OK)
@@ -137,6 +141,7 @@ ask_user_for_profile_name(user_data_t* data)
   gtk_widget_destroy(dialog);
   if(ret == GTK_RESPONSE_OK)
   {
+    g_strstrip(new_profile);
     return new_profile;
   }
   else
