@@ -254,13 +254,15 @@ void set_profile_status_icon_value(editor_data_t* data)
   {
     GtkWidget* image;
     GdkPixbuf* pixbuf = NULL;
-    gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
-			     icon_name,
-			     18, GTK_ICON_LOOKUP_NO_SVG, NULL);
+    pixbuf = gtk_icon_theme_load_icon(gtk_icon_theme_get_default(),
+				      icon_name,
+				      18, GTK_ICON_LOOKUP_NO_SVG, NULL);
     if(!pixbuf)
     {
-      pixbuf = gdk_pixbuf_new_from_file_at_size(icon_name,
+      gchar* icon_path = g_build_filename("/home/user/.profiled/", icon_name, NULL);
+      pixbuf = gdk_pixbuf_new_from_file_at_size(icon_path,
 						18, 18, NULL);
+      g_free(icon_path);
     }
     image = gtk_image_new_from_pixbuf(pixbuf);
     g_object_unref(pixbuf);
