@@ -139,7 +139,7 @@ show_profile_selection_dlg(GtkButton* button, ProfilesxStatusPlugin* plugin)
 
   GtkWidget* pannable_area;
   GtkWidget* content_area;
-  GtkWidget* dialog = gtk_dialog_new_with_buttons("Profiles",
+  GtkWidget* dialog = gtk_dialog_new_with_buttons(dgettext("osso-profiles", "profi_ti_select_profiles"),
 						  NULL,
 						  GTK_DIALOG_MODAL,
 						  dgettext("hildon-libs", "wdgt_bd_done"), GTK_RESPONSE_OK, NULL);
